@@ -3,6 +3,7 @@ mod asum;
 mod axpy;
 mod gemm;
 mod herk;
+mod nrm2;
 mod syrk;
 
 pub use amax::ITamax;
@@ -10,6 +11,7 @@ pub use asum::RTasum;
 pub use axpy::Taxpy;
 pub use gemm::Tgemm;
 pub use herk::Therk;
+pub use nrm2::Tnrm2;
 pub use syrk::Tsyrk;
 
 pub trait BlasScalar:
@@ -18,6 +20,7 @@ pub trait BlasScalar:
     Taxpy +
     Tgemm +
     Therk +
+    Tnrm2 +
     Tsyrk
  { }
 
